package com.pdaaphm.biz.service;

import java.util.List;
import com.pdaaphm.biz.domain.AlgorithmSubType;

/**
 * 算法子类型Service接口
 * 
 * @author allen
 * @date 2023-07-26
 */
public interface IAlgorithmSubTypeService 
{
    /**
     * 查询算法子类型
     * 
     * @param id 算法子类型主键
     * @return 算法子类型
     */
    public AlgorithmSubType selectAlgorithmSubTypeById(Long id);

    /**
     * 查询算法子类型列表
     * 
     * @param algorithmSubType 算法子类型
     * @return 算法子类型集合
     */
    public List<AlgorithmSubType> selectAlgorithmSubTypeList(AlgorithmSubType algorithmSubType);

    /**
     * 新增算法子类型
     * 
     * @param algorithmSubType 算法子类型
     * @return 结果
     */
    public int insertAlgorithmSubType(AlgorithmSubType algorithmSubType);

    /**
     * 修改算法子类型
     * 
     * @param algorithmSubType 算法子类型
     * @return 结果
     */
    public int updateAlgorithmSubType(AlgorithmSubType algorithmSubType);

    /**
     * 批量删除算法子类型
     * 
     * @param ids 需要删除的算法子类型主键集合
     * @return 结果
     */
    public int deleteAlgorithmSubTypeByIds(Long[] ids);

    /**
     * 删除算法子类型信息
     * 
     * @param id 算法子类型主键
     * @return 结果
     */
    public int deleteAlgorithmSubTypeById(Long id);
}
